CollectionInfo object and related elements
==========================================

.. automodule:: sarpy.io.complex.sicd_elements.CollectionInfo
    :members:
    :show-inheritance:
    :inherited-members:
